UTF64
A revolutionary text encoding standard that uses a fixed 64 bits per character.
UTF64 provides consistent O(1) character indexing and simplified implementation by encoding each Unicode character in exactly 8 bytes. The upper 32 bits contain the UTF-8 encoding of the character, while the lower 32 bits are reserved for future enhancements.
Example
use utf64::String64;
let text = String64::from("Hello, 世界!");
assert_eq!(text.len(), 10);
let decoded: String = text.to_string().unwrap();
assert_eq!(decoded, "Hello, 世界!");Re-exports
pub use error::Result;pub use error::Utf64Error;pub use string64::String64;